"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.findNearest = exports.sortItems = exports.calcPage = void 0;

var _objectValue = require("./objectValue");

var calcPage = function calcPage(allRows, itemsPerPageSetting, currentPageNumOrLast, totalRecordFromServer) {
  var result = {
    rows: [],
    pageList: [],
    allPages: [],
    rowsPerPageOptions: [5, 10, 20, 40],
    pagingMessage: "No Records",
    hasError: false,
    errorMessage: "",
    errorMessageDetail: "",
    hasPaging: true,
    showPrevButton: true,
    showNextButton: true,
    currentPageNum: currentPageNumOrLast
  };
  var itemsPerPage = findNearest(result.rowsPerPageOptions, itemsPerPageSetting);

  try {
    var pagesToShow = 4;
    var calcTotalRecordCount = totalRecordFromServer || allRows.length;
    var calcTotalPages = Math.ceil(calcTotalRecordCount / itemsPerPage);

    for (var pageAllIndex = 1; pageAllIndex <= calcTotalPages; pageAllIndex++) {
      result.allPages.push(pageAllIndex);
    }

    result.hasPaging = calcTotalPages > 1;
    var currentPageNum = currentPageNumOrLast === true ? calcTotalPages : currentPageNumOrLast;
    result.currentPageNum = currentPageNum;
    var startPage = currentPageNum > 2 ? currentPageNum - 1 : 1;
    var calcIndexStart = 0; //if the page number exceeds the total number of pages or is less than zero go to page 1

    if (currentPageNum <= calcTotalPages && currentPageNum > 0) calcIndexStart = (currentPageNum - 1) * itemsPerPage;else {
      startPage = 1;
      result.currentPageNum = 1;
    }
    var endPage = startPage + pagesToShow - 1 < calcTotalPages ? startPage + pagesToShow - 1 : calcTotalPages; //check to make sure we have the correct number of pages showing.

    if (endPage - startPage < pagesToShow - 1 && calcTotalRecordCount > 0 && endPage >= pagesToShow) {
      startPage = endPage - pagesToShow + 1;
    }

    if (startPage < 0) startPage = 1;

    for (var pageIndex = startPage; pageIndex <= endPage; pageIndex++) {
      result.pageList.push(pageIndex);
    }

    var endItemIndex = calcIndexStart + itemsPerPage < calcTotalRecordCount ? calcIndexStart + itemsPerPage : calcTotalRecordCount;
    result.pagingMessage = totalRecordFromServer > 0 || calcTotalRecordCount > 0 ? "".concat(calcIndexStart + 1, "-").concat(endItemIndex, " of ").concat(calcTotalRecordCount) : "No Data";
    result.totalRows = calcTotalRecordCount;
    result.itemsPerPage = itemsPerPage;
    result.rows = totalRecordFromServer ? allRows : allRows.slice(calcIndexStart, endItemIndex);
    result.showPrevButton = result.currentPageNum > 1;
    result.showNextButton = result.currentPageNum < calcTotalPages;
  } catch (ex) {
    result.hasError = true;
    result.pagingMessage = "ERROR";
    result.errorMessage = "Invalid input when creating table paging";
    result.errorMessageDetail = ex.message || ex;
    result.currentPageNum = 0;
  }

  return result;
};

exports.calcPage = calcPage;

var sortItems = function sortItems(itemList, sortField, isDescending) {
  itemList.sort(function (aIn, bIn) {
    var aValue = (0, _objectValue.getObjectValue)(aIn, sortField);
    var bValue = (0, _objectValue.getObjectValue)(bIn, sortField);

    if (aValue.toLowerCase && bValue.toLowerCase) {
      if (aValue.toLowerCase() < bValue.toLowerCase()) return isDescending ? 1 : -1;
      if (aValue.toLowerCase() > bValue.toLowerCase()) return isDescending ? -1 : 1;
    } else {
      if (aValue < bValue) return isDescending ? 1 : -1;
      if (aValue > bValue) return isDescending ? -1 : 1;
    }

    return 0;
  });
};

exports.sortItems = sortItems;

var findNearest = function findNearest(numList, target) {
  return numList.reduce(function (prev, curr) {
    return Math.abs(curr - target) < Math.abs(prev - target) ? curr : prev;
  });
};

exports.findNearest = findNearest;